@@ -4,9 +4,11 @@
 mod cipher;
 pub mod config;
 pub mod context;
-pub mod error;
+mod error;
 mod key_derivation;
 pub mod option;
 pub mod protection_profile;
 pub mod session;
 pub mod stream;
+
+pub use error::Error;
